@@ -2,6 +2,10 @@ from .svs_base import SVSyncBase
 from .svs import SVSync
 from .svs_shared import SVSyncShared
 
+from .svs_thread_base import SVSyncBase_Thread
+from .svs_thread import SVSync_Thread
+from .svs_shared_thread import SVSyncShared_Thread
+
 from .svs_core import SVSyncCore
 
 from .svs_core import MissingData
